import { Constructor } from '@loopback/core';
import { AuthenticationMetadata } from '../types';
/**
 * Mark a controller method as requiring authenticated user.
 *
 * @param strategyNameOrMetadata - The name of the authentication strategy to use
 * or the authentication metadata object.
 * @param options - Additional options to configure the authentication.
 */
export declare function authenticate(strategyNameOrMetadata: string | AuthenticationMetadata, options?: object): (target: any, method?: string | undefined, methodDescriptor?: TypedPropertyDescriptor<any> | undefined) => any;
export declare namespace authenticate {
    /**
     * `@authenticate.skip()` - a sugar decorator to skip authentication
     */
    const skip: () => (target: any, method?: string | undefined, methodDescriptor?: TypedPropertyDescriptor<any> | undefined) => any;
}
/**
 * Fetch authentication metadata stored by `@authenticate` decorator.
 *
 * @param targetClass - Target controller
 * @param methodName - Target method
 */
export declare function getAuthenticateMetadata(targetClass: Constructor<{}>, methodName: string): AuthenticationMetadata | undefined;
